@@ -1,11 +1,12 @@
 package Search::Tools::HeatMap;
-use strict;
-use warnings;
+use Moo;
 use Carp;
 use Data::Dump qw( dump );
-use base qw( Search::Tools::Object );
+extends 'Search::Tools::Object';
 
-our $VERSION = '0.99';
+use namespace::sweep;
+
+our $VERSION = '1.000';
 
 # debugging only
 my $OPEN  = '[';
@@ -16,18 +17,20 @@ if ( !$@ ) {
     $CLOSE = Term::ANSIColor::color('reset') . $CLOSE;
 }
 
-__PACKAGE__->mk_accessors(
-    qw( window_size
-        tokens
-        spans
-        as_sentences
-        _treat_phrases_as_singles
-        _qre
-        _query
-        _stemmer
-        )
+my @attrs = qw( window_size
+    tokens
+    spans
+    as_sentences
+    _treat_phrases_as_singles
+    _qre
+    _query
+    _stemmer
 );
 
+for my $attr (@attrs) {
+    has $attr => ( is => 'rw' );
+}
+
 =head1 NAME
 
 Search::Tools::HeatMap - locate the best matches in a snippet extract
@@ -76,15 +79,14 @@ someone wants to abuse and/or improve it.
 Create a new HeatMap. The I<TokenList> object may be either a
 Search::Tools::TokenList or Search::Tools::TokenListPP object.
 
-=head2 init
+=head2 BUILD
 
 Builds the HeatMap object. Called internally by new().
 
 =cut
 
-sub init {
+sub BUILD {
     my $self = shift;
-    $self->SUPER::init(@_);
     $self->_build;
     return $self;
 }
