@@ -1,9 +1,8 @@
 package Search::Tools::TokenListUtils;
-use strict;
-use warnings;
+use Moo::Role;
 use Carp;
 
-our $VERSION = '0.99';
+our $VERSION = '1.000';
 
 =head1 NAME
 
