@@ -1,18 +1,22 @@
 package Search::Tools::TokenPP;
-use strict;
-use warnings;
-use base qw( Search::Tools::Object );
+use Moo;
+extends 'Search::Tools::Object';
 use Carp;
 use overload
     '""'     => sub { $_[0]->str; },
     'bool'   => sub { $_[0]->len; },
     fallback => 1;
 
-our $VERSION = '0.99';
+use namespace::sweep;
 
-__PACKAGE__->mk_accessors(
-    qw( is_match is_hot pos str len u8len is_sentence_start is_sentence_end )
-);
+our $VERSION = '1.000';
+
+my @attrs
+    = qw( is_match is_hot pos str len u8len is_sentence_start is_sentence_end );
+
+for my $attr (@attrs) {
+    has $attr => ( is => 'rw' );
+}
 
 sub set_hot   { $_[0]->is_hot( $_[1] ); }
 sub set_match { $_[0]->is_match( $_[1] ); }
